@@ -3,14 +3,18 @@
  *
  * All rights reserved.
  *
- * This file is part of ObjFW. It may be distributed under the terms of the
- * Q Public License 1.0, which can be found in the file LICENSE.QPL included in
- * the packaging of this file.
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License version 3.0 only,
+ * as published by the Free Software Foundation.
  *
- * Alternatively, it may be distributed under the terms of the GNU General
- * Public License, either version 2 or 3, which can be found in the file
- * LICENSE.GPLv2 or LICENSE.GPLv3 respectively included in the packaging of this
- * file.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * version 3.0 for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * version 3.0 along with this program. If not, see
+ * <https://www.gnu.org/licenses/>.
  */
 
 #import "OFObject.h"
@@ -26,7 +30,9 @@ OF_ASSUME_NONNULL_BEGIN
 #ifdef OF_HAVE_CLASS_PROPERTIES
 @property (class, readonly, nonatomic) OFColor *black;
 @property (class, readonly, nonatomic) OFColor *silver;
-@property (class, readonly, nonatomic) OFColor *grey;
+@property (class, readonly, nonatomic) OFColor *gray;
+@property (class, readonly, nonatomic) OFColor *grey
+    OF_DEPRECATED(ObjFW, 1, 1, "Use gray instead");
 @property (class, readonly, nonatomic) OFColor *white;
 @property (class, readonly, nonatomic) OFColor *maroon;
 @property (class, readonly, nonatomic) OFColor *red;
@@ -76,13 +82,24 @@ OF_ASSUME_NONNULL_BEGIN
 + (OFColor *)silver;
 
 /**
- * @brief Returns the HTML color `grey`.
+ * @brief Returns the HTML color `gray`.
  *
  * The RGBA value is (0.5, 0.5, 0.5, 1).
  *
- * @return The HTML color `grey`
+ * @return The HTML color `gray`
  */
-+ (OFColor *)grey;
++ (OFColor *)gray;
+
+/**
+ * @brief Returns the HTML color `gray`.
+ *
+ * @deprecated Use @ref gray instead.
+ *
+ * The RGBA value is (0.5, 0.5, 0.5, 1).
+ *
+ * @return The HTML color `gray`
+ */
++ (OFColor *)grey OF_DEPRECATED(ObjFW, 1, 1, "Use gray instead");
 
 /**
  * @brief Returns the HTML color `white`.
