@@ -3,14 +3,18 @@
  *
  * All rights reserved.
  *
- * This file is part of ObjFW. It may be distributed under the terms of the
- * Q Public License 1.0, which can be found in the file LICENSE.QPL included in
- * the packaging of this file.
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License version 3.0 only,
+ * as published by the Free Software Foundation.
  *
- * Alternatively, it may be distributed under the terms of the GNU General
- * Public License, either version 2 or 3, which can be found in the file
- * LICENSE.GPLv2 or LICENSE.GPLv3 respectively included in the packaging of this
- * file.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * version 3.0 for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * version 3.0 along with this program. If not, see
+ * <https://www.gnu.org/licenses/>.
  */
 
 #import "OFObject.h"
@@ -21,6 +25,8 @@
 
 OF_ASSUME_NONNULL_BEGIN
 
+/** @file */
+
 @class OFArray OF_GENERIC(ObjectType);
 @class OFString;
 @class OFValue;
@@ -188,9 +194,21 @@ OF_ASSUME_NONNULL_BEGIN
 #ifdef __cplusplus
 extern "C" {
 #endif
+/**
+ * @brief Converts the specified error number (from `<errno.h>`) to a string.
+ *
+ * Unlike the system function `strerror`, this function is always thread-safe.
+ *
+ * As an addition, on Windows, it is also able to convert socket error numbers
+ * to string.
+ *
+ * @param errNo The error number to convert to a string
+ * @return A string describing the error
+ */
 extern OFString *OFStrError(int errNo);
+
 #ifdef OF_WINDOWS
-extern OFString *OFWindowsStatusToString(LSTATUS status);
+extern OFString *_OFWindowsStatusToString(LSTATUS status) OF_VISIBILITY_HIDDEN;
 #endif
 #ifdef __cplusplus
 }
