@@ -3,14 +3,18 @@
  *
  * All rights reserved.
  *
- * This file is part of ObjFW. It may be distributed under the terms of the
- * Q Public License 1.0, which can be found in the file LICENSE.QPL included in
- * the packaging of this file.
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License version 3.0 only,
+ * as published by the Free Software Foundation.
  *
- * Alternatively, it may be distributed under the terms of the GNU General
- * Public License, either version 2 or 3, which can be found in the file
- * LICENSE.GPLv2 or LICENSE.GPLv3 respectively included in the packaging of this
- * file.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * version 3.0 for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * version 3.0 along with this program. If not, see
+ * <https://www.gnu.org/licenses/>.
  */
 
 #import "OFIRI.h"
@@ -18,7 +22,7 @@
 OF_ASSUME_NONNULL_BEGIN
 
 /**
- * @class OFMutableIRI OFMutableIRI.h ObjFW/OFMutableIRI.h
+ * @class OFMutableIRI OFIRI.h ObjFW/OFIRI.h
  *
  * @brief A class for representing IRIs, URIs, URLs and URNs, for parsing them,
  *	  accessing parts of them as well as modifying them.
@@ -208,6 +212,23 @@ OF_ASSUME_NONNULL_BEGIN
 - (void)appendPathComponent: (OFString *)component
 		isDirectory: (bool)isDirectory;
 
+/**
+ * @brief Appends the specified path extension
+ *
+ * @param extension The path extension to append
+ */
+- (void)appendPathExtension: (OFString *)extension;
+
+/**
+ * @brief Deletes the last path component.
+ */
+- (void)deleteLastPathComponent;
+
+/**
+ * @brief Deletes the path extension.
+ */
+- (void)deletePathExtension;
+
 /**
  * @brief Resolves relative subpaths.
  */
