@@ -3,14 +3,18 @@
  *
  * All rights reserved.
  *
- * This file is part of ObjFW. It may be distributed under the terms of the
- * Q Public License 1.0, which can be found in the file LICENSE.QPL included in
- * the packaging of this file.
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License version 3.0 only,
+ * as published by the Free Software Foundation.
  *
- * Alternatively, it may be distributed under the terms of the GNU General
- * Public License, either version 2 or 3, which can be found in the file
- * LICENSE.GPLv2 or LICENSE.GPLv3 respectively included in the packaging of this
- * file.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * version 3.0 for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * version 3.0 along with this program. If not, see
+ * <https://www.gnu.org/licenses/>.
  */
 
 #include "objfw-defs.h"
@@ -1463,10 +1467,59 @@ extern void objc_autoreleasePoolPop(void *_Null_unspecified pool);
 extern id _Nullable objc_constructInstance(Class _Nullable class_,
     void *_Nullable bytes);
 extern void *_Nullable objc_destructInstance(id _Nullable object);
+typedef enum objc_associationPolicy {
+	OBJC_ASSOCIATION_ASSIGN	= 0,
+	OBJC_ASSOCIATION_RETAIN_NONATOMIC = 1,
+	OBJC_ASSOCIATION_RETAIN = OBJC_ASSOCIATION_RETAIN_NONATOMIC | 0x300,
+	OBJC_ASSOCIATION_COPY_NONATOMIC = 3,
+	OBJC_ASSOCIATION_COPY = OBJC_ASSOCIATION_COPY_NONATOMIC | 0x300
+} objc_associationPolicy;
+extern void objc_setAssociatedObject(id _Nonnull object,
+    const void *_Nonnull key, id _Nullable value,
+    objc_associationPolicy policy);
+extern id _Nullable objc_getAssociatedObject(id _Nonnull object,
+    const void *_Nonnull key);
+extern void objc_removeAssociatedObjects(id _Nonnull object);
 # endif
 #endif
+
+/**
+ * @brief Allocates a new object.
+ *
+ * This is useful to override @ref OFObject#alloc in a subclass that can then
+ * allocate extra memory in the same memory allocation.
+ *
+ * @param class_ The class of which to allocate an object
+ * @param extraSize Extra space after the ivars to allocate
+ * @param extraAlignment Alignment of the extra space after the ivars
+ * @param extra A pointer to set to a pointer to the extra space
+ * @return The allocated object
+ */
 extern id OFAllocObject(Class class_, size_t extraSize, size_t extraAlignment,
     void *_Nullable *_Nullable extra);
+
+/**
+ * @brief This function is called when a method is not found.
+ *
+ * It can also be called intentionally to indicate that a method is not
+ * implemetned, for example in an abstract method. However, instead of calling
+ * OFMethodNotFound directly, it is preferred to do the following:
+ *
+ *     - (void)abstractMethod
+ *     {
+ *     	OF_UNRECOGNIZED_SELECTOR
+ *     }
+ *
+ * However, do not use this for init methods. Instead, use the following:
+ *
+ *     - (instancetype)init
+ *     {
+ *     	OF_INVALID_INIT_METHOD
+ *     }
+ *
+ * @param self The object which does not have the method
+ * @param _cmd The selector of the method that does not exist
+ */
 extern void OF_NO_RETURN_FUNC OFMethodNotFound(id self, SEL _cmd);
 
 /**
