@@ -3,14 +3,18 @@
  *
  * All rights reserved.
  *
- * This file is part of ObjFW. It may be distributed under the terms of the
- * Q Public License 1.0, which can be found in the file LICENSE.QPL included in
- * the packaging of this file.
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License version 3.0 only,
+ * as published by the Free Software Foundation.
  *
- * Alternatively, it may be distributed under the terms of the GNU General
- * Public License, either version 2 or 3, which can be found in the file
- * LICENSE.GPLv2 or LICENSE.GPLv3 respectively included in the packaging of this
- * file.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * version 3.0 for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * version 3.0 along with this program. If not, see
+ * <https://www.gnu.org/licenses/>.
  */
 
 #include "objfw-defs.h"
@@ -295,6 +299,17 @@ extern unsigned long OFSocketAddressHash(
 extern OFString *_Nonnull OFSocketAddressString(
     const OFSocketAddress *_Nonnull address);
 
+/**
+ * @brief Returns a description for the specified @ref OFSocketAddress.
+ *
+ * This is similar to @ref OFSocketAddressString, but it also contains the port.
+ *
+ * @param address The address to return a description for
+ * @return The address as an string, with the port
+ */
+extern OFString *_Nonnull OFSocketAddressDescription(
+    const OFSocketAddress *_Nonnull address);
+
 /**
  * @brief Sets the IP port of the specified @ref OFSocketAddress.
  *
@@ -428,20 +443,20 @@ extern void OFSocketAddressSetAppleTalkPort(OFSocketAddress *_Nonnull address,
 extern uint8_t OFSocketAddressAppleTalkPort(
     const OFSocketAddress *_Nonnull address);
 
-extern bool OFSocketInit(void);
+extern bool _OFSocketInit(void) OF_VISIBILITY_HIDDEN;
 #if defined(OF_HAVE_THREADS) && defined(OF_AMIGAOS) && !defined(OF_MORPHOS)
-extern void OFSocketDeinit(void);
+extern void _OFSocketDeinit(void) OF_VISIBILITY_HIDDEN;
 #endif
-extern int OFSocketErrNo(void);
+extern int _OFSocketErrNo(void) OF_VISIBILITY_HIDDEN;
 #if !defined(OF_WII) && !defined(OF_NINTENDO_3DS)
-extern int OFGetSockName(OFSocketHandle sock, struct sockaddr *restrict addr,
-    socklen_t *restrict addrLen);
+extern int _OFGetSockName(OFSocketHandle sock, struct sockaddr *restrict addr,
+    socklen_t *restrict addrLen) OF_VISIBILITY_HIDDEN;
 #endif
 
 #if defined(OF_HAVE_THREADS) && defined(OF_AMIGAOS) && !defined(OF_MORPHOS)
-extern OFTLSKey OFSocketBaseKey;
+extern OFTLSKey _OFSocketBaseKey OF_VISIBILITY_HIDDEN;
 # ifdef OF_AMIGAOS4
-extern OFTLSKey OFSocketInterfaceKey;
+extern OFTLSKey _OFSocketInterfaceKey OF_VISIBILITY_HIDDEN;
 # endif
 #endif
 #ifdef __cplusplus
