@@ -3,14 +3,18 @@
  *
  * All rights reserved.
  *
- * This file is part of ObjFW. It may be distributed under the terms of the
- * Q Public License 1.0, which can be found in the file LICENSE.QPL included in
- * the packaging of this file.
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License version 3.0 only,
+ * as published by the Free Software Foundation.
  *
- * Alternatively, it may be distributed under the terms of the GNU General
- * Public License, either version 2 or 3, which can be found in the file
- * LICENSE.GPLv2 or LICENSE.GPLv3 respectively included in the packaging of this
- * file.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * version 3.0 for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * version 3.0 along with this program. If not, see
+ * <https://www.gnu.org/licenses/>.
  */
 
 #ifndef __STDC_LIMIT_MACROS
@@ -865,7 +869,7 @@ typedef OFString *_Nullable (^OFStreamAsyncWriteStringBlock)(
  *	  stream occurs.
  *
  * @param delimiter The delimiter
- * @return The line that was read, autoreleased, or `nil` if the end of the
+ * @return The string that was read, autoreleased, or `nil` if the end of the
  *	   stream has been reached.
  * @throw OFReadFailedException Reading failed
  * @throw OFInvalidEncodingException The string read from the stream has
@@ -880,7 +884,7 @@ typedef OFString *_Nullable (^OFStreamAsyncWriteStringBlock)(
  *
  * @param delimiter The delimiter
  * @param encoding The encoding used by the stream
- * @return The line that was read, autoreleased, or `nil` if the end of the
+ * @return The string that was read, autoreleased, or `nil` if the end of the
  *	   stream has been reached.
  * @throw OFReadFailedException Reading failed
  * @throw OFInvalidEncodingException The string read from the stream has
@@ -896,7 +900,7 @@ typedef OFString *_Nullable (^OFStreamAsyncWriteStringBlock)(
  *	  enough data has been received yet.
  *
  * @param delimiter The delimiter
- * @return The line that was read, autoreleased, or `nil` if the end of the
+ * @return The string that was read, autoreleased, or `nil` if the end of the
  *	   stream has been reached.
  * @throw OFReadFailedException Reading failed
  * @throw OFInvalidEncodingException The string read from the stream has
@@ -912,7 +916,7 @@ typedef OFString *_Nullable (^OFStreamAsyncWriteStringBlock)(
  *
  * @param delimiter The delimiter
  * @param encoding The encoding used by the stream
- * @return The line that was read, autoreleased, or `nil` if the end of the
+ * @return The string that was read, autoreleased, or `nil` if the end of the
  *	   stream has been reached.
  * @throw OFReadFailedException Reading failed
  * @throw OFInvalidEncodingException The string read from the stream has
@@ -1391,6 +1395,19 @@ typedef OFString *_Nullable (^OFStreamAsyncWriteStringBlock)(
  * @return Whether the lowlevel is at the end of the stream
  */
 - (bool)lowlevelIsAtEndOfStream;
+
+/**
+ * @brief Returns whether the lowlevel has data in the read buffer.
+ *
+ * @warning Do not call this directly!
+ *
+ * @note Override this method in case your stream can buffer data itself, such
+ *	 as when implementing @ref OFTLSStream. If not overridden, it always
+ *	 returns false.
+ *
+ * @return Whether the lowlevel has data in the read buffer
+ */
+- (bool)lowlevelHasDataInReadBuffer;
 @end
 
 OF_ASSUME_NONNULL_END
