@@ -3,14 +3,18 @@
  *
  * All rights reserved.
  *
- * This file is part of ObjFW. It may be distributed under the terms of the
- * Q Public License 1.0, which can be found in the file LICENSE.QPL included in
- * the packaging of this file.
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License version 3.0 only,
+ * as published by the Free Software Foundation.
  *
- * Alternatively, it may be distributed under the terms of the GNU General
- * Public License, either version 2 or 3, which can be found in the file
- * LICENSE.GPLv2 or LICENSE.GPLv3 respectively included in the packaging of this
- * file.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * version 3.0 for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * version 3.0 along with this program. If not, see
+ * <https://www.gnu.org/licenses/>.
  */
 
 #ifndef __STDC_LIMIT_MACROS
@@ -1331,11 +1335,26 @@ extern OFStringEncoding OFStringEncodingParseName(OFString *name);
  */
 extern OFString *_Nullable OFStringEncodingName(OFStringEncoding encoding);
 
-extern char *_Nullable OFStrDup(const char *_Nonnull);
-extern size_t OFUTF8StringEncode(OFUnichar, char *);
-extern ssize_t OFUTF8StringDecode(const char *, size_t, OFUnichar *);
-extern size_t OFUTF16StringLength(const OFChar16 *);
-extern size_t OFUTF32StringLength(const OFChar32 *);
+/**
+ * @brief Returns the length of the specified UTF-16 string.
+ *
+ * @param string The UTF-16 string
+ * @return The length of the specified UTF-16 string
+ */
+extern size_t OFUTF16StringLength(const OFChar16 *string);
+
+/**
+ * @brief Returns the length of the specified UTF-32 string.
+ *
+ * @param string The UTF-32 string
+ * @return The length of the specified UTF-32 string
+ */
+extern size_t OFUTF32StringLength(const OFChar32 *string);
+
+extern char *_Nullable _OFStrDup(const char *_Nonnull) OF_VISIBILITY_HIDDEN;
+extern size_t _OFUTF8StringEncode(OFUnichar, char *) OF_VISIBILITY_HIDDEN;
+extern ssize_t _OFUTF8StringDecode(const char *, size_t, OFUnichar *)
+    OF_VISIBILITY_HIDDEN;
 #ifdef __cplusplus
 }
 #endif
