@@ -3,14 +3,18 @@
  *
  * All rights reserved.
  *
- * This file is part of ObjFW. It may be distributed under the terms of the
- * Q Public License 1.0, which can be found in the file LICENSE.QPL included in
- * the packaging of this file.
+ * This program is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License version 3.0 only,
+ * as published by the Free Software Foundation.
  *
- * Alternatively, it may be distributed under the terms of the GNU General
- * Public License, either version 2 or 3, which can be found in the file
- * LICENSE.GPLv2 or LICENSE.GPLv3 respectively included in the packaging of this
- * file.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
+ * version 3.0 for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * version 3.0 along with this program. If not, see
+ * <https://www.gnu.org/licenses/>.
  */
 
 #ifndef OBJFWRT_OBJFWRT_H
@@ -173,10 +177,25 @@ struct objc_super {
 #endif
 };
 
+/**
+ * @brief A policy for object association, see @ref objc_setAssociatedObject.
+ */
+typedef enum objc_associationPolicy {
+	/** @brief Associate the object like an assigned property. */
+	OBJC_ASSOCIATION_ASSIGN	= 0,
+	/** @brief Associate the object like a retained, nonatomic property. */
+	OBJC_ASSOCIATION_RETAIN_NONATOMIC = 1,
+	/** @brief Associate the object like a retained property. */
+	OBJC_ASSOCIATION_RETAIN = OBJC_ASSOCIATION_RETAIN_NONATOMIC | 0x300,
+	/** @brief Associate the object like a copied, nonatomic property. */
+	OBJC_ASSOCIATION_COPY_NONATOMIC = 3,
+	/** @brief Associate the object like a copied property. */
+	OBJC_ASSOCIATION_COPY = OBJC_ASSOCIATION_COPY_NONATOMIC | 0x300
+} objc_associationPolicy;
+
 #ifdef __cplusplus
 extern "C" {
 #endif
-
 /**
  * @brief Registers a selector with the specified name with the runtime.
  *
@@ -646,6 +665,37 @@ extern uintptr_t object_getTaggedPointerValue(id _Nonnull object);
  */
 extern id _Nullable objc_createTaggedPointer(int class_, uintptr_t value);
 
+/**
+ * @brief Sets an associated object on the specified object for the specified
+ *	  key.
+ *
+ * @param object The object on which to set an associated object
+ * @param key A unique pointer to use as the key for the association
+ * @param value The object to associate with the specified object
+ * @param policy The association policy, see @ref objc_associationPolicy
+ */
+extern void objc_setAssociatedObject(id _Nonnull object,
+    const void *_Nonnull key, id _Nullable value,
+    objc_associationPolicy policy);
+
+/**
+ * @brief Returns the associated object on the specified object for the
+ *	  specified key.
+ *
+ * @param object The object on which to get the associated object
+ * @param key The key of the association
+ * @return The associated object on the specified object for the specified key
+ */
+extern id _Nullable objc_getAssociatedObject(id _Nonnull object,
+    const void *_Nonnull key);
+
+/**
+ * @brief Removes all associated objects for the specified object.
+ *
+ * @param object The object on which to remove all associated objects
+ */
+extern void objc_removeAssociatedObjects(id _Nonnull object);
+
 /*
  * Used by the compiler, but can also be called manually.
  *
